@@ -1550,7 +1550,7 @@ image/ief					ief
 # image/jls
 # image/jp2
 image/jp2					jp2
-image/jpeg					jpeg jpg jpe
+image/jpeg					jpeg jpg jpe jfif
 # image/jpm
 # image/jpx
 image/ktx					ktx
